Learn R Programming

informR (version 1.0-5)

atus80ord: Ordinal Events Subset of the American Time Use Survey

Description

Event histories from respondents over the age of 80 in the pooled 2003--2008 American Time Use Survey.

Usage

data(atus80ord)

Arguments

Format

A data frame with 62,352 observations on the following 3 variables.
Activities
Type of activity spell. See details.
TUCASEID
Respondent unique identification number.
SEX
Sex of respondent. 1=Males.

Bureau of Labor Statistics. The American Time Use Survey. Available online at: http://www.bls.gov/tus/.

Details

Each activity was recoded into a general activity class with 14 possible values (including ``missing'' as NA).

Examples

Run this code
data(atus80ord)
#Activity Spell Frequencies by Sex
table(atus80ord$Activities,atus80ord$SEX)

Run the code above in your browser using DataLab