Rdocumentation
powered by
Learn R Programming
informR (version 1.0-5)
regmat.ind: Regular Expresstion Matrix Index
Description
Internal function for generating a matrix of regular expression position matches, usually mapped to a vector expansion of the input string.
Usage
regmat.ind(reg,evl,...)
Arguments
reg
character, The regular expression.
evl
eventlist, The eventlist on which regex in
reg
is to be performed.
...
additional parameters to pass to
gregexpr()
.
Value
A three column matrix of integers.