rem() in Butts's relevent package.
sfl2sl(sformlist,exclude=NULL,eventlist=NULL)
sfl2statslist(sformlist,type=1)class(sformlist)eventlist if non-null.sfl2sl is an internal function used by gen.sformlist and should not normally be of any use to users.sfl2statslist, however, will nicely convert any object returned by gen.sformlist or glb.sformlist
into a statslist object. This is useful for constructing s-form models without intercepts passed from gen.intercepts.
gen.sformlist, slbind