atus80int:
Interval Events Subset of the American Time Use Survey
Description
Event histories from respondents over the age of 80 in the pooled 2003--2008 American Time Use Survey.
Usage
data(atus80int)
Arguments
Format
A data frame with 124,704 observations on the following 4 variables:
Events
Type of event. See details.
Time
Cumulative time that an event occurred. See details.
TUCASEID
Respondent unique identification number.
SEX
Sex of respondent. 1=Males.
Bureau of Labor Statistics. The American Time Use Survey. Available online at: http://www.bls.gov/tus/.
Details
Each general sequential activity spell in the American Time Use Survey for respondents aged 80 and over was split into ``starting'' and ``stopping'' events.
The timing variable marks the instantaneous ``time'' of event occurrence in minutes beginning at time 0 and ending at time t (which is usually 1400). Because simultaneous events are not allowed one thousandth of a minute is added to the starting time of each activity spell after the first spell.